@@ -182,6 +182,15 @@ class MatrixWithCoords:
         
         return ret
     
+    def bkg_cor(self, dbkg, scale_factor=1.0, in_place=True):
+        if not np.array_equal(self.xc, dbkg.xc) or not np.array_equal(self.xc, dbkg.xc) or self.datatype!=dbkg.datatype:
+            raise Exception("attempted background subtraction using imcompatiple data.")
+        if in_place:
+            self.d -= np.asarray(dbkg.d*scale_factor, dtype=self.d.dtype)
+        else:
+            ret = copy.deepcopy(self)
+            ret.d = self.d - dbkg.d*scale_factor
+    
     def merge(self, datalist):
         """ merge with the list of data given, not necessarily having the same coordinates
         """
@@ -204,6 +213,7 @@ class Data2d:
         self.qrqz_data = MatrixWithCoords()
         self.qphi_data = MatrixWithCoords()
         self.label = label
+        self.md = {}
         
         if isinstance(img, str):
             f = fabio.open(img)
@@ -374,6 +384,7 @@ class Axes2dPlot:
         self.ptns = []
         self.xlim = None
         self.ylim = None
+        self.img = None
         self.coordinate_translation = None
         self.exp = exp
         self.n_step = 121
@@ -392,8 +403,7 @@ class Axes2dPlot:
     def clicked(self, event):
         if event.inaxes != self.ax:
             return True
-        toolbar = plt.get_current_fig_manager().toolbar
-        x = event.xdata 
+        x = event.xdatta 
         y = event.ydata 
         if self.coordinate_translation=="xy2qrqz":
             (q, phi, qr, qz) = self.exp.calc_from_XY(np.asarray([x]),np.asarray([y]))
@@ -402,29 +412,32 @@ class Axes2dPlot:
             (q, phi, qr, qz) = self.exp.calc_from_XY(np.asarray([x]),np.asarray([y]))
             msg = "q=%.4f, phi=%.1f" % (q[0],phi[0])
         else:
-            msg = f"({x}, {y})"
-        toolbar.set_message(msg)
+            msg = f"({x:.1f}, {y:.1f})"
+        self.ax.set_title(msg, fontsize="small")
+        print(msg)
         return True
 
     # best modify d2.xc/d2.yc instead of using xscale/yscale
-    def plot(self, mask=None, log=False, aspect=1., xscale=1., yscale=1.):
+    def plot(self, showMask=None, logScale=False, mask_alpha=0.1,
+             aspect=1., xscale=1., yscale=1.):
 
         dd = np.asarray(self.d2.d, dtype=np.float)
-        if mask is not None:
-            dd[mask.map] = np.nan
 
         immax = np.average(dd) + 5 * np.std(dd)
         immin = np.average(dd) - 5 * np.std(dd)
         if immin < 0:
             immin = 0
 
-        if log:
-            self.img = self.ax.imshow(dd, aspect=aspect,
+        if showMask and self.exp:
+            self.ax.imshow(self.exp.mask.map, cmap="gray")
+        if logScale:
+            self.img = self.ax.imshow(dd, aspect=aspect, alpha=1-mask_alpha,
                                       cmap=self.cmap, interpolation='nearest', norm=LogNorm(),
                                       extent=[self.d2.xc[0]*xscale, self.d2.xc[-1]*xscale, 
                                               self.d2.yc[0]*yscale, self.d2.yc[-1]*yscale])
         else:
-            self.img = self.ax.imshow(dd, vmax=immax, vmin=immin, aspect=aspect,
+            self.img = self.ax.imshow(dd, vmax=immax, vmin=immin, 
+                                      aspect=aspect, alpha=1-mask_alpha,
                                       cmap=self.cmap, interpolation='nearest',
                                       extent=[self.d2.xc[0]*xscale, self.d2.xc[-1]*xscale, 
                                               self.d2.yc[0]*yscale, self.d2.yc[-1]*yscale]) 
@@ -437,7 +450,8 @@ class Axes2dPlot:
         if not gamma == 1:
             cmap = cmap_map(lambda x: np.exp(gamma * np.log(x)), cmap)
         self.cmap = cmap
-        self.img.set_cmap(cmap)
+        if self.img is not None:
+            self.img.set_cmap(cmap)
 
     # xvalues and yvalues should be arrays of the same length, positons to be markes
     # used to mark a pixel position, in all types of 2D maps, or a (qr,qz) or (p,phi) pair on the detector image
@@ -519,6 +533,8 @@ class Axes2dPlot:
             q_std = [ 2.0116, 2.3219, 3.2838, 3.8504 ]
         elif std=="LaB6": # NIST SRM 660c
             q_std = [ 1.5115, 2.1376, 2.6180, 3.0230, 3.3799, 3.7025 ]
+        elif isinstance(std, list):
+            q_std = np.asarray(std, dtype=np.float)
         else: # unknown standard
             return 
         self.mark_coords(q_std, [], sym, DataType.q)
